
-----------------------
-- KEYBOARD BINDINGS
-----------------------
BINDING_HEADER_MODELVIEWER = "Model Viewer"
BINDING_NAME_MODELVIEWER_VIEWMODEL = "View Model"

frameBorderSize = 10;
mouseFacing = 0;
cursorX = 0;
cursorY = 0;

function ModelViewerMainFrame_OnLoad(self)
    ModelViewerMainFrame:RegisterEvent("PLAYER_TARGET_CHANGED");

    ModelViewerMainFrame:RegisterForDrag("LeftButton", "RightButton");

    ModelViewerMainFrame:SetScript("OnEvent", function(self, event, ...) ModelViewerMainFrame_OnEvent(self, event, ...); end);
    ModelViewerMainFrame:SetScript("OnUpdate", function(self, event, ...) ModelViewerMainFrame_OnUpdate(self, event, ...); end);
    ModelViewerMainFrame:SetScript("OnMouseUp", function(self, button) ModelViewerMainFrame_OnMouseUp(self, button); end);
    ModelViewerMainFrame:SetScript("OnMouseDown", function(self, button) ModelViewerMainFrame_OnMouseDown(self, button); end);
    ModelViewerMainFrame:SetScript("OnDragStart", function() ModelViewerMainFrame_OnDragStart(); end);
    ModelViewerMainFrame:SetScript("OnDragStop", function() ModelViewerMainFrame_OnDragStop(); end);

    tinsert(UISpecialFrames, "ModelViewerMainFrame"); -- Hidw Main Frame on ESC Pressed.
end

function ModelViewerMainFrame_OnEvent(self, event, ...)
    if (event == "PLAYER_TARGET_CHANGED") then
        ModelViewerMainFrame_SetUnit();
    end
end

function ModelViewerMainFrame_SetUnit()    
    unitid = nil;
    if (UnitExists("target")) then
        unitid = "target";
        ModelViewerUnitFrame:SetUnit(unitid);

        if ModelViewerUnitFrame:IsVisible() then
            ModelViewerMainFrame_Show();
        end
    else 
        ModelViewerMainFrame_Hide();
    end
end

function ModelViewer_ViewModel_OnPress()
    if (ModelViewerMainFrame:IsVisible()) then
    --if (DressUpFrame:IsVisible()) then
        ModelViewerMainFrame_Hide();
    else
        if (unitid == nil) then
            unitid = "player";
            ModelViewerUnitFrame:SetUnit(unitid);
        end
        ModelViewerMainFrame_Show();
    end
end

function ModelViewerMainFrame_OnMouseDown(self, button)
    cursorX, cursorY = GetCursorPosition();

    if (button == "LeftButton") then
        mouseFacing = 1; -- Model Rotation Start.
    end
end

function ModelViewerMainFrame_OnMouseUp(self, button)
    local cx, cy = GetCursorPosition();
    if cursorX == cx and cursorY == cy then
        ModelViewerMainFrame_Hide();        
    end
    mouseFacing = 0; -- Model Rotation End.
end

function ModelViewerMainFrame_OnDragStart()

end

function ModelViewerMainFrame_OnDragStop()
    mouseFacing = 0;    
end

function ModelViewerMainFrame_OnUpdate()
    -------------------------------
    -- Update Model Rotation.
    -------------------------------
    if (mouseFacing == 1) then
        local cx, cy = GetCursorPosition();
        ModelViewerUnitFrame:SetFacing(ModelViewerUnitFrame:GetFacing() + ((cx - cursorX) / 50));
        cursorX, cursorY = GetCursorPosition();
    end
end

function ModelViewerMainFrame_Show()
    if (unitid == nil) then
        return;
    end

    PlaySound("GAMEDIALOGOPEN", "master"); -- http://wowwiki.wikia.com/wiki/API_PlaySound

    local scale = UIParent:GetEffectiveScale();
    local width = GetScreenWidth() * scale;
    local height = GetScreenHeight() * scale;

    width = width - (width / 2.75);
    height = height - (height / 8);

    -------------
    -- 창 크기
    -------------
    ModelViewerMainFrame:SetWidth(width);
    ModelViewerMainFrame:SetHeight(height);
    ModelViewerMainFrame:ClearAllPoints();
    ModelViewerMainFrame:SetPoint("CENTER", "UIParent");
    ModelViewerMainFrame:Show();
    --ModelViewerMainFrame:SetFrameStrata(largeWinStrata);

    --------------
    -- 모델 크기
    --------------
    width = height;
    ModelViewerUnitFrame:SetFacing(0);
    ModelViewerUnitFrame:SetWidth(width - frameBorderSize);
    ModelViewerUnitFrame:SetHeight(height - frameBorderSize);
    
    UnitInfoLayer_Show();

    if (CanInspect(unitid)) then
        InspectUnit(unitid); -- Show Blizzard Inspect UI.
        --[[
        DressUpFrame.mode = unitid;
        DressUpFrame.width = 600;
        local race, fileName = UnitRace(unitid);
        SetDressUpBackground(DressUpFrame, fileName);
        DressUpModel:SetUnit(unitid);
        ShowUIPanel(DressUpFrame);
        ]]
    end
end

function ModelViewerMainFrame_Hide()
    if ModelViewerMainFrame:IsVisible() then
        PlaySound("GAMEDIALOGCLOSE", "master"); -- http://wowwiki.wikia.com/wiki/API_PlaySound
    end

    ModelViewerMainFrame:Hide();

    if InspectFrame:IsVisible() then
        HideUIPanel(InspectFrame); -- Hide Blizzard Inspect UI.
        --HideUIPanel(DressUpFrame);
    end
end

function UnitInfoLayer_Show()

    local name, realm = UnitName(unitid);

    if (unitid == nil or unitid == "unit" or name == nil) then

    else
        ModelViewerStringName:Show();
        ModelViewerStringName:SetText(name);

        local class, classFileName = UnitClass(unitid);
        local color = RAID_CLASS_COLORS[classFileName];
        ModelViewerStringClass:Show();
        ModelViewerStringClass:SetText(class);
        ModelViewerStringClass:SetTextColor(color.r, color.g, color.b, 1);

        ModelViewerStringLevel:Show();
        ModelViewerStringLevel:SetText("Level "..UnitLevel(unitid));

        local factionGroup, factionName = UnitFactionGroup(unitid);
        if factionName == nil then
            factionName = UnitCreatureType(unitid);
        end
        if UnitIsEnemy("player", unitid) then
            ModelViewerStringFaction:SetTextColor(1, 0, 0, 1); -- Red
        else
            ModelViewerStringFaction:SetTextColor(0, 1, 0, 1); -- Green
        end
        ModelViewerStringFaction:Show();
        ModelViewerStringFaction:SetText(factionName);

        local guildName, guildRankName, guildRankIndex = GetGuildInfo(unitid);
        if guildName then
            text = guildName.." / ".. guildRankName;
            ModelViewerStringGuild:Show();
            ModelViewerStringGuild:SetText(text);
        else
            ModelViewerStringGuild:Hide();
        end

        --if UnitCreatureFamily(unitid) then text = text.." / "..UnitCreatureFamily(unitid); end
        --if UnitClassification(unitid) then text = text.." / "..UnitClassification(unitid); end
    end
end

function UnitInfoLayer_Hide()
    ModelViewerStringName:Hide();
    ModelViewerStringClass:Hide();
    ModelViewerStringLevel:Hide();
    ModelViewerStringFaction:Hide();
    ModelViewerStringGuild:Hide();
end 
